function mtx = denavitHartenberg(notation)
%DENAVITHARTENBERG Creates a 4x4 matrix for Denavit-Hartenberg notation
%
% Input arguments:
%   notation(1) = alpha - rotation over new x axis
%   notation(2) = a     - translation in new x axis
%   notation(3) = theta - rotation over z axis
%   notation(4) = d     - translation in z axis
% Return value:
%   mtx: Transformation matrix
% 
% MITSUBISHI MELFA TOOLBOX v1.4
% (C) Martin Meloun
% 
% Mitsubishi Melfa Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU Lesser General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% Mitsubishi Melfa Toolbox is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Lesser General Public License for more details.
% 
% You should have received a copy of the GNU Leser General Public License
% along with Mitsubishi Melfa Toolbox. If not, see <http://www.gnu.org/licenses/>.
% 
% Author:                  Revision:     Date:                    Reason:
% Martin Meloun                    1     25.5.2010 15:28:05       Initial revision

mtx = [ cos(notation(3)), -sin(notation(3))*cos(notation(1)),  sin(notation(3))*sin(notation(1)), notation(2)*cos(notation(3));
        sin(notation(3)),  cos(notation(3))*cos(notation(1)), -cos(notation(3))*sin(notation(1)), notation(2)*sin(notation(3));
        0,                 sin(notation(1)),                   cos(notation(1)),                  notation(4);
        0,                 0,                                  0,                                 1];
end
