function mm()
% Common arguments:
%
% r:
%	The whole tooblox uses this return value as a notification that
%	communication with the robot was successful. This only checks whether
%	there was an error in the communication e.g commanding the robot to go
%	outside its working area is not a communication error therefore. Some
%	function have a 'Safe' variant; that means that a proper error checking
%	is done after the command (usually returns 'rs' instead of 'r'. The 'r'
%	is equal to 0 for success, any other value is error.
%	
% robot:
% The handle for the robot unit, derived from hgsetget, so you can use the
% 'get' and 'set' functions. Required for almost all functions. It is
% created in mmOpen or mmOpen2 when specifying the robot name. The handle
% is invalidated by calling mmClose.
%
% Function overview:
%
% mmAcquireCom                   .. Acquires this com port for a robot.
% mmClose                        .. Closes communication with robot.
% mmCntlOff                      .. Turns off control for that robot.
% mmCntlOn                       .. Turns on control for that robot.
% mmComprops_Serial              .. Creates serial object properties structure. The properties' names must match to the serial object properties' names.
% mmCreateCoords                 .. Creates the coordinate system string for Melfa.
% mmCreateRobot                  .. Creates a instance of a robot structure.
% mmDemo                         .. Runs a demonstration sequence.
% mmDkt                          .. The direct kinematic task.
% mmError                        .. Raises an error in the controller (currently by hack).
% mmExec                         .. Sends a MELFA command to robot and reads the reply.
% mmExecSafe                     .. Sends a MELFA command to robot, reads the reply and checks for error.
% mmFlush                        .. Flushes robot comport.
% mmGetAcceleration              .. Gets the acceleration and deceleration constants.
% mmGetBaseSpeed                 .. Gets the base speed constant.
% mmGetFlags                     .. Gets the position flags.
% mmGetInterpolationSpeed        .. Gets the interpolation speed constant.
% mmGetJogSpeed                  .. Gets the jog speed constant.
% mmGetPos                       .. Returns the current position in selected coordinates.
% mmGetPos2                      .. Returns the coordinates of selected type.
% mmGetState                     .. Retutns the current robot state.
% mmGetVar                       .. Reads a variable and returns its value.
% mmIkt                          .. The inverse kinematic task (specific for each robot).
% mmIsFreeCom                    .. Whether the communication is not acquired.
% mmMov                          .. Moves the robot to specified position using joint interpolation.
% mmMovLin                       .. Moves the robot using linear interpolation.
% mmMovLinSafe                   .. Exact operation as mmMovLin with error checking right after.
% mmMovSafe                      .. Exact operation as mmMov with error checking right after.
% mmMovToolZ                     .. Moves the robot using linear interpolation.
% mmMovToolZSafe                 .. Exact operation as mmMovToolZ with error checking right after.
% mmOpen                         .. Opens the Melfa Robot Communication.
% mmOpen2                        .. Opens the Melfa Robot Communication over an existing com object.
% mmOpenVirt                     .. Opens a virtual Melfa Robot.
% mmOwnsCom                      .. Whether the communication is acquired by the robot.
% mmParseRunState                .. Parses the run state bitfield into structure.
% mmParseStopState               .. Parses the stop state bitfield into structure.
% mmPlotRecordedMove             .. Plots the robot recorded moving.
% mmPlotRobot                    .. Plots the robot rigid body with specified coordinates.
% mmPlotTrajectory               .. Plots a trajectory.
% mmPrecisionType                .. Sets the precision type.
% mmPrintf                       .. Writes a line to the com port.
% mmPurge                        .. Clears errors.
% mmReadyToMove                  .. Checks if the robot is ready to move.
% mmReleaseCom                   .. Releases the com for another robot.
% mmRobots                       .. Lists available Melfa Robots implemented in the toolbox.
% mmrtCreateInteractiveRobot     .. Creates Robot Toolbox robot instance.
% mmrtDriveBot                   .. Executes Robot Toolbox DriveBot function.
% mmrtPlotJointMove              .. Plots the robot moving from A to B position in joint interp.
% mmrtPlotLinearMove             .. Plots the robot moving from A to B position in linear interp.
% mmrtPlotRecordedMove           .. Plots the robot recorded moving (using Robot Toolbox).
% mmrtPlotRobot                  .. Plots the robot rigid body with specified coordinates.
% mmrtRecordingStart             .. Starts robot movement recording. The samples must be added manually.
% mmrtRecordingStop              .. Stops robot movement recording.
% mmrtRecordingTakeSample        .. Records the sample.
% mmrtRecordTillStop             .. Records the robot until the robot is in stop state.
% mmScanf                        .. Reads a line from the communication port.
% mmSendCmd                      .. Sends a command to robot and reads the reply.
% mmSendCmdSafe                  .. Sends a command to robot, reads the reply and checks error.
% mmSetAcceleration              .. Sets the acceleration and deceleration constants.
% mmSetBaseSpeed                 .. Sets the base speed constant.
% mmSetInterpolationSpeed        .. Gets the interpolation speed constant.
% mmSetJogSpeed                  .. Sets the jog speed constant.
% mmSetVar                       .. Assigns a value for a variable.
% mmSetVar2                      .. Assigns a variable from another variable.
% mmSimulateMove                 .. Simulates movement from A to B.
% mmSrvOff                       .. Turns off servo for that robot.
% mmSrvOn                        .. Turns on servo for that robot.
% mmStop                         .. Stops the robot.
% mmTestKinematics               .. Tests inverse kinematic task (requires correct direct kinematic task).
% mmTraceJoint                   .. Traces the robot moving from A to B position in joint interp.
% mmTraceLinear                  .. Traces the robot moving from A to B position in linear interp.
% mmWaitForServoOff              .. Waits until the servomotor is off.
% mmWaitForServoOn               .. Waits until the servomotor is on.
% mmWaitForStop                  .. Waits until the robot is in stop state.
% anglesToMtx                    .. Converts yaw, pitch and roll to rotation matrix.
% denavitHartenberg              .. Creates a 4x4 matrix for Denavit-Hartenberg notation.
% hat                            .. High Accuracy Timer.
% mtxRotateX                     .. Creates a rotation matrix over axis x.
% mtxRotateY                     .. Creates a rotation matrix over axis y.
% mtxRotateZ                     .. Creates a rotation matrix over axis z.
% mtxToAngles                    .. Converts rotation matrix to yaw, pitch and roll.
% mtxTranslate                   .. Creates a translation matrix.
% substr                         .. Extracts a substring out of a string.
%
	error('Only to be used as ''help mm''.');
end