function mmDemo_RV6SDL()
%MMDEMO_RV6SDL The demonstration sequence for Mitsubishi RV-6SDL.
% 
% MITSUBISHI MELFA TOOLBOX v1.4
% (C) Martin Meloun
% 
% Mitsubishi Melfa Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU Lesser General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% Mitsubishi Melfa Toolbox is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Lesser General Public License for more details.
% 
% You should have received a copy of the GNU Leser General Public License
% along with Mitsubishi Melfa Toolbox. If not, see <http://www.gnu.org/licenses/>.
% 
% Author:                  Revision:     Date:                    Reason:
% Martin Meloun                    1     25.5.2010 15:28:05       Initial revision

%open the robot communication with default properties
robot = mmOpen('RV6SDL');

%turn on control
mmCntlOn(robot);

%turn on servomotor
mmSrvOn(robot);

%set base speed coeficient
mmSetBaseSpeed(robot, 50);

%set jog speed coeficient
mmSetJogSpeed(robot, 100);

%create the conformations
n = 15;
conformations = cell(1, n);

conformations{1}  = [  0;  0;  0;  0;  0;  0];
conformations{2}  = [  0;  0; 90;  0; 90;  0];
conformations{3}  = [  0; 90;  0;  0; 90;  0];
conformations{4}  = [  0; 90;  0; 90; 90;  0];
conformations{5}  = [  0; 90;  0;-90; 90;  0];
conformations{6}  = [  0; 90;  0;  0; 90;  0];
conformations{7}  = [  0; 30; 60;  0;  0;  0];
conformations{8}  = [-30; 30; 60;  0;  0; 60];
conformations{9}  = [ 30; 30; 60;  0;  0;-60];
conformations{10} = [  0; 30; 60;  0;  0;  0];
conformations{11} = [  0;-50;140;  0;  0;  0];
conformations{12} = [-60;-50;140; 45; 45;-45];
conformations{13} = [ 60;-50;140;-45; 45; 45];
conformations{14} = [  0;-50;140;  0;  0;  0];
conformations{15} = [  0;  0;  0;  0;  0;  0];

%wait until the servomotor is on
r = mmWaitForServoOn(robot);

%check for error
if (r)
  mmClose(robot);
  error('Failed to turn on servo motors.');
end

%iterate through each conformation
for i=1:n
  %move in jog coordinates
  [~, r1] = mmMovSafe(robot, 'J', conformations{i});
  
  %wait until finished
  [r2] = mmWaitForStop(robot);
  
  %quit if error
  if ( r1 || r2 )
      mmClose(robot);
      error('Robot is in error state.');
  end
end

%all done, close communication
mmClose(robot);

end
