function P = mmDkt(robot, J)
%MMDKT The direct kinematic task.
%COMMONARGS robot
%
% P = mmDkt(robot, J);
%
% Arguments:
%   J: Joint coordinates
% 
% Return values:
%   P: P = [x; y; z; A; B; C] - Position and rotation column vector, where
%      x, y, z are the coordinates and A, B, C are yaw, pitch and roll.
% 
% MITSUBISHI MELFA TOOLBOX v1.4
% (C) Martin Meloun
% 
% Mitsubishi Melfa Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU Lesser General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% Mitsubishi Melfa Toolbox is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Lesser General Public License for more details.
% 
% You should have received a copy of the GNU Leser General Public License
% along with Mitsubishi Melfa Toolbox. If not, see <http://www.gnu.org/licenses/>.
% 
% Author:                  Revision:     Date:                    Reason:
% Martin Meloun                    1     25.5.2010 15:28:05       Initial revision


J = J*pi/180; %deg to rad
T = robot.base;

for i=1:size(robot.denavitHartenberg, 2)
  T = T * denavitHartenberg(robot.denavitHartenberg(:,i) + ...
                J(i) * robot.denavitHartenbergParameters(:,i));
end

T = T * robot.tool;
X = T * [0; 0; 0; 1];
[A B C] = mtxToAngles(T);

P = [X(1); X(2); X(3); A; B; C];

end
