function [reply rs] = mmExecSafe(robot, tmplt, varargin)
%MMEXECSAFE Sends a MELFA command to robot, reads the reply and checks for error.
%COMMONARGS robot
%
% Equal to mmExec function only right after the reply is read the state of
% the robot is requested to see if it is in error state.
%
% [reply rs] = mmExecSafe(robot, command);
% [reply rs] = mmExecSafe(robot, format, ...);
%
% Arguments:
%   tmplt:  the command, can as well be in form of a string template (with
%           proper variable arguments).
% 
% Return values:
%   reply:  The robot's answer
%   rs:     0 if there is no error, 1 communication error, otherwise error
%           number
% 
% MITSUBISHI MELFA TOOLBOX v1.4
% (C) Martin Meloun
% 
% Mitsubishi Melfa Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU Lesser General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% Mitsubishi Melfa Toolbox is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Lesser General Public License for more details.
% 
% You should have received a copy of the GNU Leser General Public License
% along with Mitsubishi Melfa Toolbox. If not, see <http://www.gnu.org/licenses/>.
% 
% Author:                  Revision:     Date:                    Reason:
% Martin Meloun                    1     30.4.2010 17:05:56       Initial revision

[reply rs] = mmExec(robot, tmplt, varargin);

if (rs == 0)
    %ensure it is really ok
    [~, ~, errno] = mmGetState(robot);
    rs = errno;
end

end
