function flags = mmGetFlags_RV6S_Series(robot, jCoords)
%MMGETFLAGS_RV6S_SERIES Obtain flags for robots for RV-6S / RV-6SDL.
%See the manual for mmGetFlags.
% 
% MITSUBISHI MELFA TOOLBOX v1.4
% (C) Martin Meloun
% 
% Mitsubishi Melfa Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU Lesser General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% Mitsubishi Melfa Toolbox is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Lesser General Public License for more details.
% 
% You should have received a copy of the GNU Leser General Public License
% along with Mitsubishi Melfa Toolbox. If not, see <http://www.gnu.org/licenses/>.
% 
% Author:                  Revision:     Date:                    Reason:
% Martin Meloun                    1     18.7.2011 14:54:38       Initial revision

  T1p = partialDkt(robot, jCoords, 1, 1);
  T2p = partialDkt(robot, jCoords, 2, 1);
  T4 =  partialDkt(robot, jCoords, 4, 0);
  T6 =  partialDkt(robot, jCoords, 6, 0);
  T7 =  partialDkt(robot, jCoords, 6, 1); %yeah little aliasing xD
  
  J1p = T1p(1:3,4);
  J2p = T2p(1:3,4);
  J4 = T4(1:3,4);
  J6 = T6(1:3,4);
  J7 = T7(1:3,4);

  %get the flags for position
  %R/L
  %===================================================
  
  %get the normal vector of the plane
  norm = J2p - J1p;
  
  %J2p is on it
  d = -sum(norm.*J2p);
  
  %check J7 position
  df = sum(norm.*J7)+d;
  
  if (df >= 0)
    rlflag = 1;
  else
    rlflag = 0;
  end
  
  %A/B
  %===================================================
  %new normal vector
  nrmP = T2p*[0;1;0;1];
  norm = nrmP(1:3,1)-T2p(1:3,4);
  
  %J2p is on it
  d = -sum(norm.*J2p);
  
  %check J7 position
  df = sum(norm.*J7)+d;
  
  if (df >= 0)
    abflag = 1;
  else
    abflag = 0;
  end
  
  %N/F
  %===================================================
  
  %new normal vector
  nrmP = T4*[1;0;0;1];
  norm = nrmP(1:3,1) - T4(1:3,4);
  
  %J4 is on it
  d = -sum(norm.*J4);
  
  %check J6 position
  df = sum(norm.*J6)+d;
  
  if (df >= 0)
    nfflag = 0;
  else
    nfflag = 1;
  end
  
  %get the flags for periodicity
  shifted = jCoords+180;
  base = mod(shifted,360);
  
  flArray = int32((shifted-base)/360);
  flags2 = int32(0);
  for i=1:length(flArray)
    
    if (flArray(i) < 0)
      flArray(i) = flArray(i) + 16;
    end
    
    flags2 = flags2+16^(i-1)*flArray(i);
    
  end
  
  flags1 = nfflag + 2*abflag + 4*rlflag;
  flags = [flags1 flags2];

end

function T = partialDkt(robot, jCoords, transf, lasthalf)

  J = jCoords*pi/180; %deg to rad
  T = eye(4);

  for i=1:transf
    
    if ( lasthalf && (i == transf) )
      T = T * denavitHartenberg([0; 0; robot.denavitHartenberg(3,i); robot.denavitHartenberg(4,i)] + ...
                    J(i) * robot.denavitHartenbergParameters(:,i));
    else    
      T = T * denavitHartenberg(robot.denavitHartenberg(:,i) + ...
                    J(i) * robot.denavitHartenbergParameters(:,i));
    end
  end

end
