function [runst stopst errno stepno mechno] = mmGetState(robot)
%MMGETSTATE Retutns the current robot state.
%COMMONARGS robot
%
% [runst stopst errno stepno mechno] = mmGetState(robot)
%
% Return values:
%   runst:  The runstate bitfield. Use mmParseRunState to parse it into structure.
%   stopst: The stopstate bitfield. Use mmParseStopState to parse it into structure.
%   errno:  The error number. 0 means no error.
%   stepno: See the documentation for the robot.
%   mechno: See the documentation for the robot.
% 
% MITSUBISHI MELFA TOOLBOX v1.4
% (C) Martin Meloun
% 
% Mitsubishi Melfa Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU Lesser General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% Mitsubishi Melfa Toolbox is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Lesser General Public License for more details.
% 
% You should have received a copy of the GNU Leser General Public License
% along with Mitsubishi Melfa Toolbox. If not, see <http://www.gnu.org/licenses/>.
% 
% Author:                  Revision:     Date:                    Reason:
% Martin Meloun                    1     30.4.2010 17:05:56       Initial revision

reply = mmSendCmd(robot, 'DSTATE');

runst = hex2dec(substr(reply, 3, 2));
stopst = hex2dec(substr(reply, 5, 2));
colons = findstr(reply, ';');
errno = str2double(substr(reply, 7, colons(1) - 7 - 1));
stepno = str2double(substr(reply, 9, colons(2) - colons(1) - 1));
mechno = str2double(substr(reply, colons(length(colons))));

%set robot error
robot.robotError = errno;

end
