function [b, r] = mmIsFreeCom(robot)
%MMISFREECOM Whether the communication is not acquired.
%COMMONARGS r, robot
%
% Return values:
%   b:  True if the communication is not acquired.
% 
% MITSUBISHI MELFA TOOLBOX v1.4
% (C) Martin Meloun
% 
% Mitsubishi Melfa Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU Lesser General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% Mitsubishi Melfa Toolbox is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Lesser General Public License for more details.
% 
% You should have received a copy of the GNU Leser General Public License
% along with Mitsubishi Melfa Toolbox. If not, see <http://www.gnu.org/licenses/>.
% 
% Author:                  Revision:     Date:                    Reason:
% Martin Meloun                    1     30.4.2010 17:05:56       Initial revision

if (isempty(robot.com))
  robot.errorType = 'NO_COM';
  robot.errorMsg = 'Communication is not opened';
  r = 1;
  b = -1;

  if (robot.thrError)
      error('The communication is not opened.');
  end

  return;
end

b = (robot.com.acquiredToRobotNo == -1) && (robot.com.acquiredToSlotNo == -1);
r = 0;

end %func
