function runStateStruct = mmParseRunState(st)
%MMPARSERUNSTATE Parses the run state bitfield into structure.
%
% Input arguments:
%   st: run state bitfield
%
% Return values:
%   runStateStruct: structurized run state
% 
% MITSUBISHI MELFA TOOLBOX v1.4
% (C) Martin Meloun
% 
% Mitsubishi Melfa Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU Lesser General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% Mitsubishi Melfa Toolbox is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Lesser General Public License for more details.
% 
% You should have received a copy of the GNU Leser General Public License
% along with Mitsubishi Melfa Toolbox. If not, see <http://www.gnu.org/licenses/>.
% 
% Author:                  Revision:     Date:                    Reason:
% Martin Meloun                    1     30.4.2010 17:05:56       Initial revision

runStateStruct.CycleOrRepeat = bitand(st,1) ~= 0;          % 0 = Cycle, 1 = Repeat
runStateStruct.CycleStop = bitand(st,2) ~= 0;              % 0 = ON, 1 = OFF
runStateStruct.Mlock = bitand(st,4) ~= 0;                  % 0 = OFF, 1 = ON
runStateStruct.AutoOrTeach = bitand(st,8) ~= 0;            % 0 = AUTO, 1 = TEACH
runStateStruct.RunningOfTeachMode = bitand(st,16) ~= 0;    % 0 = OFF, 1 = ON
runStateStruct.ServoOn = bitand(st,32) ~= 0;               % 0 = OFF, 1 = ON
runStateStruct.Stopped = bitand(st,64) == 0;               % 0 = RUN, 1 = STOP
runStateStruct.ControlOn = bitand(st,128) ~= 0;            % 0 = OFF, 1 = ON
runStateStruct.Invalid = bitand(st,256) ~= 0;              % 0 = Valid, 1 = Invalid
    
end
