function r = mmPrintf(robot, tmplt, varargin)
%MMPRINTF Writes a line to the com port.
%COMMONARGS r, robot
%
% r = mmPrintf(robot, command);
% r = mmPrintf(robot, format, ...);
%
% Arguments:
%   tmplt:  the command, can as well be in form of a string template (with
%           proper variable arguments).
% 
% MITSUBISHI MELFA TOOLBOX v1.4
% (C) Martin Meloun
% 
% Mitsubishi Melfa Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU Lesser General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% Mitsubishi Melfa Toolbox is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Lesser General Public License for more details.
% 
% You should have received a copy of the GNU Leser General Public License
% along with Mitsubishi Melfa Toolbox. If not, see <http://www.gnu.org/licenses/>.
% 
% Author:                  Revision:     Date:                    Reason:
% Martin Meloun                    1     30.4.2010 17:05:56       Initial revision

%error checking
if (isempty(robot.com))
  robot.throwErr('NO_COM', 'The communication is not opened.');
  r = 1;
  return;
end

if (robot.com.acquiredToRobotNo ~= robot.robotNo || robot.com.acquiredToSlotNo ~= robot.slotNo)
  robot.throwErr('NO_ACCESS', 'Unauthorized attempt to use mmPrintf: The com is not acquired by robot %d and slot %d.', ...
    robot.com.acquiredToRobotNo, robot.com.acquiredToSlotNo);
  r = 1;
  return;
end

%print the robot identifier and the command
r = robot.com.printf(['%d;%d;' tmplt], robot.robotNo, robot.slotNo, varargin{:});

if (r)
  robot.throwErr('PRINTF_ERROR', 'Could not write to the comport.');
  r = 1;
  return;
end

end %func
