classdef mmRobot_RV6S  < mmRobotDef
%MMROBOT_RV6S Robot specification: Mitsubishi RV-6S.
% 
% MITSUBISHI MELFA TOOLBOX v1.4
% (C) Martin Meloun
% 
% Mitsubishi Melfa Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU Lesser General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% Mitsubishi Melfa Toolbox is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Lesser General Public License for more details.
% 
% You should have received a copy of the GNU Leser General Public License
% along with Mitsubishi Melfa Toolbox. If not, see <http://www.gnu.org/licenses/>.
% 
% Author:                  Revision:     Date:                    Reason:
% Martin Meloun                    3     4.8.2011 16:08:25        Corrected joint 6 theta parameter
% Martin Meloun                    2     12.10.2010 16:10:32      Corrected DH notation
% Martin Meloun                    1     30.4.2010 17:05:56       Initial revision

methods

  function robot = mmRobot_RV6S()

    % Name
    % ------------------------------------------------------------------------------
    robot.name = 'RV6S';
    robot.description = 'Mitsubishi Melfa RV-6S';
    robot.series = 'Melfa IV';
    robot.pincode = 0;

    % Properties
    % ------------------------------------------------------------------------------

    robot.DOF = 6;
    robot.joints = 'RRRRRR';

    robot.denavitHartenberg = [ -pi/2,     0, -pi/2,  pi/2, -pi/2,  0;  %alpha 
                                   85,   280,   100,     0,     0,  0;  %a
                                    0, -pi/2, -pi/2,     0,     0, pi;  %theta
                                  350,     0,     0,   315,     0, 85]; %d

    robot.denavitHartenbergParameters = [ 0, 0, 0, 0, 0, 0;  %alpha 
                                          0, 0, 0, 0, 0, 0;  %a
                                          1, 1, 1, 1, 1, 1;  %theta
                                          0, 0, 0, 0, 0, 0]; %d

    robot.base = eye(4);
    robot.tool = eye(4);
    robot.jointLimits = [-170, -92, -107, -160, -120, -360;  %minimums
                          170, 135,  166,  160,  120,  360]; %maximums
    robot.A76 = mtxTranslate([0; 0; robot.denavitHartenberg(4, 6)]);

    % PC Control
    % ------------------------------------------------------------------------------

    robot.com = [];                               
    robot.comtype = 'Serial';
    robot.portname = 'COM3';
    robot.controller = 'CR2B-574';
    robot.robotNo = 1;
    robot.slotNo = 1; 
    robot.comprops = mmComprops_Serial(38400, 8, 'even', 2, 'on', 'on', 'CR');
    robot.topVariableSign = '<';
    robot.ikt = @mmIkt_RV6S_Series;
    robot.testKinematics = @mmTestKinematics_RV6S_Series;
    robot.getflags = @mmGetFlags_RV6S_Series;

    % Debugging
    robot.verbose = 0;
    robot.thrError = 0;


    % HardHome
    % ------------------------------------------------------------------------------

    robot.hhflag = 2;     

    % Userdata
    % ------------------------------------------------------------------------------

    robot.userdata = [];
    
    % Security (none - base definition)
    % ------------------------------------------------------------------------------

    robot.safetyData = [];
    robot.secureMovement = 0;
    robot.secureSpeed = 0;
    robot.secureAccel = 0;
        
  end
  
end

end
