function [line r] = mmScanf(robot)
%MMSCANF Reads a line from the communication port.
%COMMONARGS r, robot
%
% [reply r] = mmScanf(robot);
% 
% Return values:
%   line: The robot's answer
% 
% MITSUBISHI MELFA TOOLBOX v1.4
% (C) Martin Meloun
% 
% Mitsubishi Melfa Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU Lesser General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% Mitsubishi Melfa Toolbox is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Lesser General Public License for more details.
% 
% You should have received a copy of the GNU Leser General Public License
% along with Mitsubishi Melfa Toolbox. If not, see <http://www.gnu.org/licenses/>.
% 
% Author:                  Revision:     Date:                    Reason:
% Martin Meloun                    1     30.4.2010 17:05:56       Initial revision

%error checking
if (isempty(robot.com))
  line = 'ERROR';
  r = 1;

  robot.throwErr('NO_COM', 'The communication is not opened.');
  return;
end

if (robot.com.acquiredToRobotNo ~= robot.robotNo || robot.com.acquiredToSlotNo ~= robot.slotNo)
  line = 'ERROR';
  r = 1;
  
  robot.throwErr('NO_ACCESS', 'Unauthorized attempt to use mmScanf: The com is not acquired by robot %d and slot %d.', ...
          robot.com.acquiredToRobotNo, robot.com.acquiredToSlotNo);
  return;
end

%read the line from the comport
[line,r] = robot.com.scanf();

if (r)
  line = 'ERROR';
  r = 1;
  robot.throwErr('SCANF_ERROR', 'Could not read the comport');
  return;
end

%verify the message is for me
c = strfind(line, 'QoK');

%throw an error if not ok
if ((isempty(line)) || isempty(c) || (c(1) ~= 1))
  mline = line;
  enters = strfind(line, '\n');
  returns = strfind(line, '\r');
  mline(enters) = ' ';
  mline(returns) = ' ';
  robot.throwErr('REPLY_ERROR', 'The line read is: %s: %s', robot.errorMsg, mline);
  r = 1;
else
  r = 0;
end

end %func
