function [correctCount incorrectCount incorrectConformations testedConformations] ...
  = mmTestKinematics_RV6S_Series(robot)
%MMTESTKINEMATICS_RV6S_SERIES Tests inverse kinematic task for for robots for RV-6S / RV-6SDL.
%See the manual for mmTestKinematics.
% 
% MITSUBISHI MELFA TOOLBOX v1.4
% (C) Martin Meloun
% 
% Mitsubishi Melfa Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU Lesser General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% Mitsubishi Melfa Toolbox is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Lesser General Public License for more details.
% 
% You should have received a copy of the GNU Leser General Public License
% along with Mitsubishi Melfa Toolbox. If not, see <http://www.gnu.org/licenses/>.
% 
% Author:                  Revision:     Date:                    Reason:
% Martin Meloun                    1     25.5.2010 15:28:05       Initial revision

myeps = 10000*eps;
myeps2 = 100000000*eps;

nsCorrect = 0;
nsIncorrect = 0;
sg3Correct = 0;
sg3Incorrect = 0;
sg5Correct = 0;
sg5Incorrect = 0;
sg35Correct = 0;
sg35Incorrect = 0;
neCorrect = 0;
neIncorrect = 0;
neMthdFail = 0;
incorrectIndex = 1;

incorrectConformations = zeros(6,40000);
testedConformations = zeros(6,40000);

incorrectConformations(:,:) = NaN;
testedConformations(:,:) = NaN;

dktTime = 0;
iktTime = 0;

%generate 2000 random joint coordinates
J = rand(6,2000);

for i=1:6
  J(i,:) = (J(i,:) - 0.5) * (robot.jointLimits(2,i) - robot.jointLimits(1,i));
end

%test em
for i=1:2000
  %skip if singular
  if (abs(J(3,i)) < myeps)
    continue;
  end
  
  if (abs(J(5,i)) < myeps)
    continue;
  end
  
  %dkt first
  t0=clock;
  P = mmDkt(robot, J(:,i));
  dktTime = dktTime + etime(clock,t0) * 1000; 
  
  t0=clock;
  X = mmIkt(robot, P);
  iktTime = iktTime + etime(clock,t0) * 1000; 
  
  for j=1:size(X,2)
    P2 = mmDkt(robot, X(:,j));
    diff = sum(abs(P2-P));
    
    if (diff > myeps2)
      nsIncorrect = nsIncorrect + 1;
      incorrectConformations(:, incorrectIndex) = X(:,j);
      testedConformations(:, incorrectIndex) = J(:,i);
      incorrectIndex = incorrectIndex + 1;
    else
      nsCorrect = nsCorrect + 1;
    end
  end
end

%singularize J3
for i=1:2000
  
  %skip if J5 is singular 
  if (abs(J(5,i)) < myeps)
    continue;
  end
  
  %dkt first
  J3 = J(:,i);
  J3(3) = 0;
  
  t0=clock;
  P = mmDkt(robot, J3);
  dktTime = dktTime + etime(clock,t0) * 1000; 
  
  t0=clock;
  X = mmIkt(robot, P);
  iktTime = iktTime + etime(clock,t0) * 1000; 
  
  for j=1:size(X,2)
    P2 = mmDkt(robot, X(:,j));
    diff = sum(abs(P2-P));
    
    if (diff > myeps2)
      sg3Incorrect = sg3Incorrect + 1;
      incorrectConformations(:, incorrectIndex) = X(:,j);
      testedConformations(:, incorrectIndex) = J3;
      incorrectIndex = incorrectIndex + 1;
    else
      sg3Correct = sg3Correct + 1;
    end
  end
end


%singularize J5
for i=1:2000
  
  %skip if J3 is singular 
  if (abs(J(3,i)) < myeps)
    continue;
  end
  
  %dkt first
  J5 = J(:,i);
  J5(5) = 0;
  
  t0=clock;
  P = mmDkt(robot, J5);
  dktTime = dktTime + etime(clock,t0) * 1000; 
  
  t0=clock;
  X = mmIkt(robot, P);
  iktTime = iktTime + etime(clock,t0) * 1000; 
  
  for j=1:size(X,2)
    P2 = mmDkt(robot, X(:,j));
    diff = sum(abs(P2-P));
    
    if (diff > myeps2)
      sg5Incorrect = sg5Incorrect + 1;
      incorrectConformations(:, incorrectIndex) = X(:,j);
      testedConformations(:, incorrectIndex) = J5;
      incorrectIndex = incorrectIndex + 1;
    else
      sg5Correct = sg5Correct + 1;
    end
  end
end

%singularize J3 and J5
for i=1:2000
    
  %dkt first
  J35 = J(:,i);
  J35(3) = 0;
  J35(5) = 0;
  
  t0=clock;
  P = mmDkt(robot, J35);
  dktTime = dktTime + etime(clock,t0) * 1000; 
  t0=clock;
  X = mmIkt(robot, P);
  iktTime = iktTime + etime(clock,t0) * 1000; 
  
  for j=1:size(X,2)
    P2 = mmDkt(robot, X(:,j));
    diff = sum(abs(P2-P));
    
    if (diff > myeps2)
      sg35Incorrect = sg35Incorrect + 1;
      incorrectConformations(:, incorrectIndex) = X(:,j);
      testedConformations(:, incorrectIndex) = J35;
      incorrectIndex = incorrectIndex + 1;
    else
      sg35Correct = sg35Correct + 1;
    end
  end
end

%test 1000 points clearly out of range

outXY = rand(2,1000) * 1000 - 500;
outZ = robot.denavitHartenberg(4,1) + robot.denavitHartenberg(2,2) + ...
  sqrt(robot.denavitHartenberg(2,3)^2 + robot.denavitHartenberg(4,4)^2) + ...
  robot.denavitHartenberg(4,6) + robot.tool(1,4) + robot.tool(2,4) + ...
  robot.tool(3,4) + 1; %make it unreachable
outABC = rand(3,1000) * 2 * pi;

for i=1:1000
  X = mmIkt(robot, [outXY(1:2, i); outZ; outABC(1:3, i)]);
  if (~isnan(X(1)))   
    %test it, in case the solution is somehow reachable
    P = mmDkt(robot, X(:,1));     
    diff = sum(abs([outXY(1:2, i); outZ; outABC(1:3, i)]-P)); 
    if (diff > myeps2)  
      neIncorrect = neIncorrect + 1;
    else
      neMthdFail = neMthdFail + 1;
      neCorrect = neCorrect + 1;
    end
  else  
    neCorrect = neCorrect + 1;
  end
end

correctCount = nsCorrect + sg3Correct + sg5Correct + sg35Correct + neCorrect;
incorrectCount = nsIncorrect + sg3Incorrect + sg5Incorrect + sg35Incorrect + neIncorrect;

total = correctCount + incorrectCount;
perc = correctCount / total * 100;

if (incorrectIndex > 1)
  incorrectConformations = incorrectConformations(:,1:incorrectIndex - 1);
  testedConformations = testedConformations(:,1:incorrectIndex - 1);
else
  incorrectConformations = [];
  testedConformations = [];
end

fprintf('==================================================================\n');
fprintf('Tested kinematics for robot %s.\n', robot.description);
fprintf('==================================================================\n');
fprintf('Total tested points was                   %d\n', total);
fprintf('Total correct solutions:                  %d\n', correctCount);
fprintf('Total incorrect solutions:                %d\n', incorrectCount);
fprintf('Total successfulness:                     %.2f%%\n', perc);
fprintf('==================================================================\n');
fprintf('Non-singular results:\n');
fprintf('Correct solutions:                        %d\n', nsCorrect);
fprintf('Incorrect solutions:                      %d\n', nsIncorrect);
fprintf('Successfulness:                           %.2f%%\n', nsCorrect / (nsCorrect + nsIncorrect) * 100);
fprintf('==================================================================\n');
fprintf('Singular state in J3 results:\n');
fprintf('Correct solutions:                        %d\n', sg3Correct);
fprintf('Incorrect solutions:                      %d\n', sg3Incorrect);
fprintf('Successfulness:                           %.2f%%\n', sg3Correct / (sg3Correct + sg3Incorrect) * 100);
fprintf('==================================================================\n');
fprintf('Singular state in J5 results:\n');
fprintf('Correct solutions:                        %d\n', sg5Correct);
fprintf('Incorrect solutions:                      %d\n', sg5Incorrect);
fprintf('Successfulness:                           %.2f%%\n', sg5Correct / (sg5Correct + sg5Incorrect) * 100);
fprintf('==================================================================\n');
fprintf('Singular state in J3 and J5 results:\n');
fprintf('Correct solutions:                        %d\n', sg35Correct);
fprintf('Incorrect solutions:                      %d\n', sg35Incorrect);
fprintf('Successfulness:                           %.2f%%\n', sg35Correct / (sg35Correct + sg35Incorrect) * 100);
fprintf('==================================================================\n');
fprintf('Unreachable positions correctly detected: %d\n', neCorrect);
fprintf('Non-existing solutions found by mistake:  %d\n', neIncorrect);
fprintf('Positions turned out to be reachable:     %d\n', neMthdFail);
fprintf('Successfulness:                           %.2f%%\n', neCorrect / (neCorrect + neIncorrect) * 100);
fprintf('==================================================================\n');
fprintf('Total dkt runtime:                        %.4f ms\n', dktTime);
fprintf('Per one solution:                         %.4f ms\n', dktTime/(total - 1000));
fprintf('==================================================================\n');
fprintf('Total ikt runtime:                        %.4f ms\n', iktTime);
fprintf('Per one solution:                         %.4f ms\n', iktTime/(total - 1000));
fprintf('==================================================================\n');
end
