function trajectory = mmTraceJoint(robot, startJCoor, endJCoor, noPoints)
%MMTRACEJOINT Traces the robot moving from A to B position in joint interp.
%COMMONARGS robot
%
% mmTraceJoint(robot, startJCoor, endJCoor [, noPoints]);
%
% Arguments:
%   startJCoor: 6x1 vector, start point joint coordinates
%   endJCoor:   6x1 vector, end point joint coordinates
% 
% Optional Arguments:
%   noPoints: If specified, the number of points calculated. Otherwise
%   estimated.
%
% Return Value:
%   6xN matrix, with the XYZ-ABC coordinates of the movement from start
%   point to end point
%
% This function traces the movement of robot from start point to end point
% in joint interpolation and returns the trajectory how the robot is going
% to move.
% 
% MITSUBISHI MELFA TOOLBOX v1.4
% (C) Martin Meloun
% 
% Mitsubishi Melfa Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU Lesser General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% Mitsubishi Melfa Toolbox is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Lesser General Public License for more details.
% 
% You should have received a copy of the GNU Leser General Public License
% along with Mitsubishi Melfa Toolbox. If not, see <http://www.gnu.org/licenses/>.
% 
% Author:                  Revision:     Date:                    Reason:
% Martin Meloun                    1     9.7.2010 14:09:47        Initial revision

  if (nargin < 4)
    dist = sqrt(sum((endJCoor - startJCoor)*2).^2); % in halves of degradians
    noPoints = round(dist);
  end

  if (noPoints < 1)
    trajectory = endJCoor;
  else

    trajectory = zeros(6, noPoints + 1);
    step = (endJCoor - startJCoor) / noPoints;

    for i=1:noPoints+1
      trajectory(:, i) = mmDkt(robot, startJCoor + (step * (i-1)));
    end
  
  end

end
