function rs = mmWaitForStop(robot, timeout, waitres)
%MMWAITFORSTOP Waits until the robot is in stop state.
%COMMONARGS robot
%
% r = mmWaitForStop(robot, timeout = 300, waitres = 0.05)
%
% Input arguments:
%   (optional) timeout: timeout in seconds
%   (optional) waitres: time resolution in seconds
%
% Return values:
%   rs: 0 if no error. 1 if timeout, other values are robot error.
% 
% MITSUBISHI MELFA TOOLBOX v1.4
% (C) Martin Meloun
% 
% Mitsubishi Melfa Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU Lesser General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% Mitsubishi Melfa Toolbox is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Lesser General Public License for more details.
% 
% You should have received a copy of the GNU Leser General Public License
% along with Mitsubishi Melfa Toolbox. If not, see <http://www.gnu.org/licenses/>.
% 
% Author:                  Revision:     Date:                    Reason:
% Martin Meloun                    1     30.4.2010 17:05:56       Initial revision

t0=hat;

if (nargin < 2)
  timeout = 300;
end

if (nargin < 3)
  waitres = 0.05;
end

while(1)
  [runst, ~, errno] = mmGetState(robot);
  runst = mmParseRunState(runst);

  if (runst.Invalid)
    rs = 1;
    break;
  elseif (runst.Stopped)
    rs = errno;
    break;
  end

  if (hat - t0 > timeout)
    rs = 1;
    break;
  end

  if (waitres > 0)
    pause(waitres);
  end
end

end
