function mmrtPlotLinearMove(robot, startJCoor, endJCoor, newfig)
%MMRTPLOTLINEARMOVE Plots the robot moving from A to B position in linear interp.
%COMMONARGS robot
%
% mmrtPlotLinearMove(robot, startJCoor, endJCoor [, newfig]);
%
% Arguments:
%   startJCoor: 6x1 vector, start point joint coordinates.
%   endJCoor:   6x1 vector, end point joint coordinates.
% 
% Optional Arguments:
%   newfig:     Do not create a new figure for plotting.
%
% This function traces the movement of robot from start point to end point
% in linear interpolation and plots it.
% 
% MITSUBISHI MELFA TOOLBOX v1.4
% (C) Martin Meloun
% 
% Mitsubishi Melfa Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU Lesser General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% Mitsubishi Melfa Toolbox is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Lesser General Public License for more details.
% 
% You should have received a copy of the GNU Leser General Public License
% along with Mitsubishi Melfa Toolbox. If not, see <http://www.gnu.org/licenses/>.
% 
% Author:                  Revision:     Date:                    Reason:
% Martin Meloun                    1     18.7.2011 14:54:38       Initial revision

  if (nargin < 4)
    newfig = 1;
  end

  data.startPoint = mmDkt(robot, startJCoor);
  data.endPoint = mmDkt(robot, endJCoor);
  data.jCoords = mmTraceLinear(robot, startJCoor, data.endPoint);
  
  if (isempty(data.jCoords))
    error('Cannot move in this direction.');
  end
  
  data.robot = robot;
  data.rtrobot = mmrtCreateInteractiveRobot(robot);
  data.startJCoor = startJCoor;
  data.endJCoor = endJCoor;
  
  max = size(data.jCoords, 2) - 1;

  if (newfig)
    data.figure = figure('Name', [robot.description ': Linear interpolation movement'], 'NumberTitle', 'off', 'ToolBar', 'figure');
  else
    data.figure = get(0, 'CurrentFigure');
  end
  
  data.plotHandle=newplot;
  
  %these are static handles
  plot(data.rtrobot, (data.startJCoor')*pi/180);
  mmPlotTrajectory(robot, [data.startPoint data.endPoint], 0, 1, 0);
  
  data.staticPlots=get(data.plotHandle, 'Children');
  
  %linear move
  uicontrol('Style','slider','Units','Normalized','Position',[.35 .94 .3 .04], 'UserData', data, 'Max', max,...
    'Callback', @Callback, 'SliderStep', [1/(max+1) 10/(max+1)]);

end

function Callback(obj, ~)

  value = round(get(obj, 'Value')); %0 - (size - 1)

  data = get(obj, 'UserData');
  set(0,'CurrentFigure', data.figure);
  jCoor = data.jCoords(:,value);
  jCoor = (jCoor')*pi/180;
  
  %clear everything except the slider and the robot 
  children=get(data.plotHandle, 'Children');
  for j=1:length(children);

    %something not to be redrawn
    if (any(data.staticPlots==children(j)))
      continue;
    end

    delete(children(j));
  end

  %robot toolbox update plot (@#***&%##*)
  r = findobj('Tag', data.rtrobot.name);
  rr = get(r, 'UserData');
  rr.q = jCoor;
  set(r, 'UserData', rr);
  
  %clear the figure
  plot(rr, jCoor);
end
