function recordData = mmrtRecordingStop(robot)
%MMRTRECORDINGSTOP Stops robot movement recording.
%COMMONARGS robot
%
% mmRecordingStop(robot)
%
% Return Value:
%   A structure with field .jCoords as the joint coordinates of the
%   trajectory and with field .times as the time notations for each of the
%   coordinate.
% 
% MITSUBISHI MELFA TOOLBOX v1.4
% (C) Martin Meloun
% 
% Mitsubishi Melfa Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU Lesser General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% Mitsubishi Melfa Toolbox is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Lesser General Public License for more details.
% 
% You should have received a copy of the GNU Leser General Public License
% along with Mitsubishi Melfa Toolbox. If not, see <http://www.gnu.org/licenses/>.
% 
% Author:                  Revision:     Date:                    Reason:
% Martin Meloun                    1     18.7.2011 14:54:38       Initial revision

if (~isfield(robot.userdata, 'tracing') || isempty(robot.userdata.tracing))
  error('The robot is not recording.');
end

if (~isempty(robot.userdata.tracing.plotTimer))
  stop(robot.userdata.tracing.plotTimer); 
  close(robot.userdata.tracing.figure);
end

%return the jCoords
start = robot.userdata.tracing.trajectory.start;

if (start < 1)
  sz = start + 2999;
  recordData.jCoords = zeros(6, sz);
  recordData.jCoords(:,1:sz) = robot.userdata.tracing.trajectory.jCoords(:,1:sz); 
  recordData.times = zeros(1, sz);
  recordData.times(1:sz) = robot.userdata.tracing.trajectory.times(1:sz); 
else
  recordData.jCoords = zeros(6, 3000);
  recordData.jCoords(:,1:3000-start+1) = robot.userdata.tracing.trajectory.jCoords(:,start:3000);
  recordData.jCoords(:,3000-start+2:3000) = robot.userdata.tracing.trajectory.jCoords(:,1:start-1); 
  recordData.times = zeros(1, 3000);
  recordData.times(1:3000-start+1) = robot.userdata.tracing.trajectory.times(start:3000);
  recordData.times(3000-start+2:3000) = robot.userdata.tracing.trajectory.times(1:start-1); 
end
  
robot.userdata.tracing = [];

end
