function mmrtRecordingTakeSample(robot, jCoords)
%MMRTRECORDINGTAKESAMPLE Records the sample.
%COMMONARGS robot
%
% mmRecordingTakeSample(robot, jCoords)
%
% Arguments:
%   jCoords: the sample to be recorded
%
% 
% MITSUBISHI MELFA TOOLBOX v1.4
% (C) Martin Meloun
% 
% Mitsubishi Melfa Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU Lesser General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% Mitsubishi Melfa Toolbox is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Lesser General Public License for more details.
% 
% You should have received a copy of the GNU Leser General Public License
% along with Mitsubishi Melfa Toolbox. If not, see <http://www.gnu.org/licenses/>.
% 
% Author:                  Revision:     Date:                    Reason:
% Martin Meloun                    1     18.7.2011 14:54:38       Initial revision

if (isnan(jCoords(1)))
  %TODO - counter for maximal number of errors before quitting
  %some error, ignore it
  return;
end

if (~isfield(robot.userdata, 'tracing') || isempty(robot.userdata.tracing))
  error('The robot is not recording.');
end

if (sum(abs(jCoords - robot.userdata.tracing.currentLocation)) < 0.001)
  %micromoves not recorded
  return;
end

robot.userdata.tracing.currentLocation = jCoords;
robot.userdata.tracing.trajectory.times(robot.userdata.tracing.trajectory.next) = hat - robot.userdata.tracing.startTime;
robot.userdata.tracing.trajectory.jCoords(:,robot.userdata.tracing.trajectory.next) = robot.userdata.tracing.currentLocation;
robot.userdata.tracing.trajectory.vals(:,robot.userdata.tracing.trajectory.next) = mmDkt(robot, robot.userdata.tracing.currentLocation);
robot.userdata.tracing.trajectory.start = robot.userdata.tracing.trajectory.start + 1;
robot.userdata.tracing.trajectory.next = robot.userdata.tracing.trajectory.next + 1;

if (robot.userdata.tracing.trajectory.start > 3000)
  robot.userdata.tracing.trajectory.start = 1;
end

if (robot.userdata.tracing.trajectory.next > 3000)
  robot.userdata.tracing.trajectory.next = 1;
end

if (~isempty(robot.userdata.tracing.external.callback))
  robot.userdata.tracing.external.callback(robot);
end

end
