function [A B C] = mtxToAngles(mtx)
%MTXTOANGLES Converts rotation matrix to yaw, pitch and roll.
%
% [A B C] = mtxToAngles(mtx)
%
% Arguments:
%   mtx: Rotation matrix.
% Return value:
%   A: yaw
%   B: pitch
%   C: roll
% 
% MITSUBISHI MELFA TOOLBOX v1.4
% (C) Martin Meloun
% 
% Mitsubishi Melfa Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU Lesser General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% Mitsubishi Melfa Toolbox is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Lesser General Public License for more details.
% 
% You should have received a copy of the GNU Leser General Public License
% along with Mitsubishi Melfa Toolbox. If not, see <http://www.gnu.org/licenses/>.
% 
% Author:                  Revision:     Date:                    Reason:
% Martin Meloun                    1     25.5.2010 15:28:05       Initial revision

myeps = 10000*eps;
s2 = -mtx(3,1);

if (abs(s2 - 1) < myeps)
  A = 0; % parameter
  B = pi/2;
  C = atan2(mtx(2,3), mtx(1,3));
elseif (abs(s2 + 1) < myeps)
  A = 0; % parameter
  B = -pi/2;
  C = atan2(-mtx(2,3), mtx(1,3));
else  
  s2 = max(s2, -1);
  s2 = min(s2, 1);
  B = asin(s2);
  c2 = sign(cos(B));
  C = atan2(mtx(2,1) / c2, mtx(1,1) / c2);
  A = atan2(mtx(3,2) / c2, mtx(3,3) / c2); 
end

A = A*180/pi;
B = B*180/pi;
C = C*180/pi;

if (nargout < 3)
  A = [A; B; C];
  
else

end
